import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable, catchError, map} from 'rxjs';
import { handleError } from '../../utils/api-error-handler.utils';
import { TableData } from '../../interfaces/table-data';
import { mapToTableData } from '../../utils/mapping.utils';
import { environment } from '../../../../evironments/environment';

@Injectable({
  providedIn: 'root'
})
export class ClientsService {

  private apiUrl = environment.apiUrl + '/api/SalesChannels';

  constructor(private http: HttpClient) {}

  getClients(): Observable<TableData[]> {
    return this.http.get<any[]>(this.apiUrl).pipe(map(data => mapToTableData(data)),catchError(handleError));
  }

  getClientById(id: number): Observable<any> {
    return this.http.get<any>(`${this.apiUrl}/${id}`).pipe(map(data => mapToTableData(data)),catchError(handleError));
  }
  createClient(client: any): Observable<any> {
    return this.http.post<any>(this.apiUrl, client).pipe(catchError(handleError));
  }

  updateClient(client: any): Observable<any> {
    return this.http.put<any>(this.apiUrl, client).pipe(catchError(handleError));
  }

  deleteClient(id: number): Observable<any> {
    return this.http.delete<any>(`${this.apiUrl}/${id}`).pipe(catchError(handleError));
  }


}
