import { Component, Input, Output, EventEmitter } from '@angular/core';
import { TableData } from '../../../core/interfaces/table-data';
import { CommonModule } from '@angular/common';
import { UsersService } from '../../../core/services/api/users.service';
@Component({
  selector: 'app-event',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './event.component.html',
  styleUrl: './event.component.scss'
})
export class EventComponent {
  @Input() event: TableData = {};
  @Output() closeEventModal = new EventEmitter<void>();

  labelTranslation: ColumnTranslations = {
    id: 'ID',
    title: 'Título',
    description: 'Descripción',
    envenDate: 'Fecha',
    user: 'Usuario'
  };


  userData: TableData = {};
  isSale: boolean = false;
  elements: string[] =[];

  constructor(private userService: UsersService) {
    if(this.event['type'] === 'sale') {
      this.isSale = true;
      this.formatDescription();
    }
  }

  closeModal() {
    this.closeEventModal.emit();
  }

  objectKeys(obj: TableData): string[] {
    return Object.keys(obj);
  }

  splitKeys(): { leftColumn: string[], rightColumn: string[] } {
    const keys = this.objectKeys(this.event);
    const middleIndex = Math.ceil(keys.length / 2);
    return {
      leftColumn: keys.slice(0, middleIndex),
      rightColumn: keys.slice(middleIndex)
    };
  }

  translateLabel(column: string): string {
    return this.labelTranslation[column] || column;
  }

  private formatDescription(){
    this.elements = this.event['description'].split(',');
  }
}

interface ColumnTranslations {
  [key: string]: string;
}
